# -*- coding: utf-8 -*-
"""
Created on Tue Nov 19 22:47:51 2019

@author: yoelr
"""
from . import jit_speed
from . import open_solvers
from . import bounded_solvers
from . import iterative_solvers
from . import least_squares_iteration
from . import problem_list
from . import profiler
from . import problem
from . import utils

__all__ = (*open_solvers.__all__,
           *bounded_solvers.__all__,
           *iterative_solvers.__all__,
           *least_squares_iteration.__all__,
           *problem_list.__all__,
           *problem.__all__,
           *profiler.__all__,
           *jit_speed.__all__,
           'utils',
)

from .jit_speed import *
from .open_solvers import *
from .bounded_solvers import *
from .iterative_solvers import *
from .least_squares_iteration import *
from .problem_list import *
from .problem import *
from .profiler import *

__version__ = '0.3.31'